# DeploymentInstanceSpec

Deployment Instance specification 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**deployment_id** | **str** | Unique identifier | 
**name** | **str** | A name used to unqiuely identify this deployment instance.  | 
**org_id** | **str** | Unique identifier | [optional] 
**description** | **str** | A description for this deployment instance  | [optional] 
**inputs** | [**[DeploymentInstanceInput]**](DeploymentInstanceInput.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


